@@ -123,9 +123,19 @@ class MozMill(object):
 
         preferences = profile_args.setdefault('preferences', {})
         if isinstance(preferences, dict):
+            # Bug 695026 - Re-enable e10s when fully supported
+            preferences['browser.tabs.remote'] = False
+            preferences['browser.tabs.autostart'] = False
+            preferences['browser.displayedE10SPrompt'] = 5
+
             preferences['extensions.jsbridge.port'] = jsbridge_port
             preferences['focusmanager.testmode'] = True
         elif isinstance(preferences, list):
+            # Bug 695026 - Re-enable e10s when fully supported
+            preferences.append(('browser.tabs.remote', False))
+            preferences.append(('browser.tabs.autostart', False))
+            preferences.append(('browser.displayedE10SPrompt', 5))
+
             preferences.append(('extensions.jsbridge.port', jsbridge_port))
             preferences.append(('focusmanager.testmode', True))
         else:
@@ -527,18 +537,24 @@ class MozMill(object):
         message = message or 'Disconnect Error: Application unexpectedly closed'
 
         test = self.running_test
-        test['passes'] = []
-        test['fails'] = [{
-          'exception': {
-            'message': message
-          }
-        }]
-        test['passed'] = 0
-        test['failed'] = 1
+        obj = {'filename': test['path'],
+               'passed': 0,
+               'failed': 1,
+               'passes': [],
+               'fails': [{
+                   'exception': {
+                       'message': message
+                   }
+               }],
+               # Bug 643480
+               # Should be consistent with test.__name__ ;
+               'name': os.path.basename(test['path'])
+        }
+
 
         # Ensure that we log this disconnect as failure
-        self.results.alltests.append(test)
-        self.results.fails.append(test)
+        self.results.alltests.append(obj)
+        self.results.fails.append(obj)
 
     def stop_runner(self):
         # Give a second for any callbacks to finish.
@@ -774,6 +790,11 @@ class CLI(mozrunner.CLI):
         profile_args.setdefault('addons', []).extend(ADDONS)
 
         profile_args['preferences'] = {
+            # Bug 695026 - Re-enable e10s when fully supported
+            'browser.displayedE10SPrompt': 5,
+            'browser.tabs.remote': False,
+            'browser.tabs.autostart': False,
+
             'extensions.jsbridge.port': self.jsbridge_port,
             'focusmanager.testmode': True
         }
