@@ -58,17 +58,23 @@ MozmillHandlers.prototype = {
 
 
 var ConsoleObserver = {
-  var errorRegEx = /\[.*(Error|Exception).*(chrome|resource):\/\/(mozmill|jsbridge).*/i;
-  var externalFileRegEx = /.*\.js -> file:\/\/\/.*/;
+  errorRegEx : /\[.*(Error|Exception).*(chrome|resource):\/\/(mozmill|jsbridge).*/i,
+  externalFileRegEx :  /.*\.js -> file:\/\/\/.*/,
 
   observe: function (aSubject, aTopic, aData) {
     var msg = aSubject.message;
 
-    if (msg.match(errorRegEx)) {
+    // If the message is not related to one of our extensions forget about it
+    if (!msg.contains('mozmill') && !msg.contains('jsbridge')) {
+      return
+    }
+
+    // Only care about errors and exceptions but not warnings and other messages
+    if (msg.match(this.errorRegEx)) {
       // If there is an exception happening in a background thread caused by a
       // test, don't raise a framework failure because the error gets forwarded
       // through the console service.
-      if (msg.match(externalFileRegEx)) {
+      if (msg.match(this.externalFileRegEx)) {
         new Expect().fail(msg);
       }
       else {
